@@ -17,7 +17,7 @@ class StringTests: XCTestCase {
         // Put teardown code here. This method is called after the invocation of each test method in the class.
     }
 
-    func testSwiftString() throws {
+    func testRunRustCallsSwiftTests() throws {
         run_string_tests()
     }
     
